==> cscec5b-wzxt-api-3.0.0-20210423.110558-232-sources.jar: com/ejianc/business/wzxt/vo/PurchaseInfo.java <==
package com.ejianc.business.wzxt.vo;

public class PurchaseInfo{
    // 订购单子表主键
    private String pkPurchaseInfo;
    // 订单表主键
    private String pkPurchase;
    // 材料主键
    private String pkMaterial;
    // 材料编码")
    private String materialCode;
    // 材料名称
    private String materialName;
    // 规格
    private String materialSpec;
    // 型号
    private String materialType;
    // 单位
    private String materialMeasname;
    // 生产厂家
    private String materialManufacturer;
    // 材料备注
    private String materialNote;
    private Double planAmountSum; // 计划数量
    private Double planUncheckAmountSum; // 计划剩余数量
    private Double stockAmountSum; // 库存数量
    private Double purchaseAmountSum; // 订单数量
    private Double purchaseCheckAmountSum; // 接收数量
    private Integer smartStatus;

    public String getPkPurchaseInfo() {
        return pkPurchaseInfo;
    }

    public void setPkPurchaseInfo(String pkPurchaseInfo) {
        this.pkPurchaseInfo = pkPurchaseInfo;
    }

    public String getPkPurchase() {
        return pkPurchase;
    }

    public void setPkPurchase(String pkPurchase) {
        this.pkPurchase = pkPurchase;
    }

    public String getPkMaterial() {
        return pkMaterial;
    }

    public void setPkMaterial(String pkMaterial) {
        this.pkMaterial = pkMaterial;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }

    public String getMaterialMeasname() {
        return materialMeasname;
    }

    public void setMaterialMeasname(String materialMeasname) {
        this.materialMeasname = materialMeasname;
    }

    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }

    public String getMaterialNote() {
        return materialNote;
    }

    public void setMaterialNote(String materialNote) {
        this.materialNote = materialNote;
    }

    public Double getPlanAmountSum() {
        return planAmountSum;
    }

    public void setPlanAmountSum(Double planAmountSum) {
        this.planAmountSum = planAmountSum;
    }

    public Double getPlanUncheckAmountSum() {
        return planUncheckAmountSum;
    }

    public void setPlanUncheckAmountSum(Double planUncheckAmountSum) {
        this.planUncheckAmountSum = planUncheckAmountSum;
    }

    public Double getStockAmountSum() {
        return stockAmountSum;
    }

    public void setStockAmountSum(Double stockAmountSum) {
        this.stockAmountSum = stockAmountSum;
    }

    public Double getPurchaseAmountSum() {
        return purchaseAmountSum;
    }

    public void setPurchaseAmountSum(Double purchaseAmountSum) {
        this.purchaseAmountSum = purchaseAmountSum;
    }

    public Double getPurchaseCheckAmountSum() {
        return purchaseCheckAmountSum;
    }

    public void setPurchaseCheckAmountSum(Double purchaseCheckAmountSum) {
        this.purchaseCheckAmountSum = purchaseCheckAmountSum;
    }

    public Integer getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(Integer smartStatus) {
        this.smartStatus = smartStatus;
    }
}

==> cscec5b-wzxt-api-3.0.0-20210730.101353-290-sources.jar: com/ejianc/business/wzxt/vo/PurchaseInfo.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;

public class PurchaseInfo{
    // 订购单子表主键
    private String pkPurchaseInfo;
    // 订单表主键
    private String pkPurchase;
    // 材料主键
    private String pkMaterial;
    // 材料编码")
    private String materialCode;
    // 材料名称
    private String materialName;
    // 规格
    private String materialSpec;
    // 型号
    private String materialType;
    // 单位
    private String materialMeasname;
    // 生产厂家
    private String materialManufacturer;
    // 材料备注
    private String materialNote;
    private Double planAmountSum; // 计划数量
    private Double planUncheckAmountSum; // 计划剩余数量
    private Double stockAmountSum; // 库存数量
    private Double purchaseAmountSum; // 订单数量
    private Double purchaseCheckAmountSum; // 接收数量
    private Integer smartStatus;

    private java.math.BigDecimal price; // 单价
    private java.math.BigDecimal taxPrice; // 含税单价
    private java.math.BigDecimal taxRate; // 税率
    private java.lang.String width; // 宽度
    private java.lang.String height; // 高度
    private java.lang.String length; // 长度
    private java.lang.String surface; // 表面处理
    private java.lang.String color; // 颜色
    private java.lang.String colorNumber; // 色号
    private java.lang.String textureMaterial; // 材质状态
    private java.lang.String wallThickness; // 壁厚要求
    private java.lang.String buildingNumber; // 栋号

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public String getWidth() {
        return width;
    }

    public void setWidth(String width) {
        this.width = width;
    }

    public String getHeight() {
        return height;
    }

    public void setHeight(String height) {
        this.height = height;
    }

    public String getLength() {
        return length;
    }

    public void setLength(String length) {
        this.length = length;
    }

    public String getSurface() {
        return surface;
    }

    public void setSurface(String surface) {
        this.surface = surface;
    }

    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }

    public String getColorNumber() {
        return colorNumber;
    }

    public void setColorNumber(String colorNumber) {
        this.colorNumber = colorNumber;
    }

    public String getTextureMaterial() {
        return textureMaterial;
    }

    public void setTextureMaterial(String textureMaterial) {
        this.textureMaterial = textureMaterial;
    }

    public String getWallThickness() {
        return wallThickness;
    }

    public void setWallThickness(String wallThickness) {
        this.wallThickness = wallThickness;
    }

    public String getBuildingNumber() {
        return buildingNumber;
    }

    public void setBuildingNumber(String buildingNumber) {
        this.buildingNumber = buildingNumber;
    }

    public String getPkPurchaseInfo() {
        return pkPurchaseInfo;
    }

    public void setPkPurchaseInfo(String pkPurchaseInfo) {
        this.pkPurchaseInfo = pkPurchaseInfo;
    }

    public String getPkPurchase() {
        return pkPurchase;
    }

    public void setPkPurchase(String pkPurchase) {
        this.pkPurchase = pkPurchase;
    }

    public String getPkMaterial() {
        return pkMaterial;
    }

    public void setPkMaterial(String pkMaterial) {
        this.pkMaterial = pkMaterial;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public String getMaterialType() {
        return materialType;
    }

    public void setMaterialType(String materialType) {
        this.materialType = materialType;
    }

    public String getMaterialMeasname() {
        return materialMeasname;
    }

    public void setMaterialMeasname(String materialMeasname) {
        this.materialMeasname = materialMeasname;
    }

    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }

    public String getMaterialNote() {
        return materialNote;
    }

    public void setMaterialNote(String materialNote) {
        this.materialNote = materialNote;
    }

    public Double getPlanAmountSum() {
        return planAmountSum;
    }

    public void setPlanAmountSum(Double planAmountSum) {
        this.planAmountSum = planAmountSum;
    }

    public Double getPlanUncheckAmountSum() {
        return planUncheckAmountSum;
    }

    public void setPlanUncheckAmountSum(Double planUncheckAmountSum) {
        this.planUncheckAmountSum = planUncheckAmountSum;
    }

    public Double getStockAmountSum() {
        return stockAmountSum;
    }

    public void setStockAmountSum(Double stockAmountSum) {
        this.stockAmountSum = stockAmountSum;
    }

    public Double getPurchaseAmountSum() {
        return purchaseAmountSum;
    }

    public void setPurchaseAmountSum(Double purchaseAmountSum) {
        this.purchaseAmountSum = purchaseAmountSum;
    }

    public Double getPurchaseCheckAmountSum() {
        return purchaseCheckAmountSum;
    }

    public void setPurchaseCheckAmountSum(Double purchaseCheckAmountSum) {
        this.purchaseCheckAmountSum = purchaseCheckAmountSum;
    }

    public Integer getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(Integer smartStatus) {
        this.smartStatus = smartStatus;
    }
}
